@@ -54,12 +54,9 @@ window_title_changed(GtkWidget *widget, gpointer win)
 static void
 icon_title_changed(GtkWidget *widget, gpointer win)
 {
-	GtkWindow *window;
-
 	g_assert(VTE_TERMINAL(widget));
 	g_assert(GTK_IS_WINDOW(win));
 	g_assert(VTE_TERMINAL(widget)->icon_title != NULL);
-	window = GTK_WINDOW(win);
 
 	g_message("Icon title changed to \"%s\".\n",
 		  VTE_TERMINAL(widget)->icon_title);
@@ -68,7 +65,6 @@ icon_title_changed(GtkWidget *widget, gpointer win)
 static void
 char_size_changed(GtkWidget *widget, guint width, guint height, gpointer data)
 {
-	VteTerminal *terminal;
 	GtkWindow *window;
 	GdkGeometry geometry;
 	GtkBorder *inner_border;
@@ -76,7 +72,6 @@ char_size_changed(GtkWidget *widget, guint width, guint height, gpointer data)
 	g_assert(GTK_IS_WINDOW(data));
 	g_assert(VTE_IS_TERMINAL(widget));
 
-	terminal = VTE_TERMINAL(widget);
 	window = GTK_WINDOW(data);
 	if (!gtk_widget_get_realized (GTK_WIDGET (window)))
 		return;
@@ -538,11 +533,7 @@ int
 main(int argc, char **argv)
 {
 	GdkScreen *screen;
-#if GTK_CHECK_VERSION (2, 90, 8)
 	GdkVisual *visual;
-#else
-	GdkColormap *colormap;
-#endif
 	GtkWidget *window, *widget,*hbox = NULL, *scrollbar, *scrolled_window = NULL;
 	VteTerminal *terminal;
 	char *env_add[] = {
@@ -797,15 +788,9 @@ main(int argc, char **argv)
 
 	/* Set ARGB colormap */
 	screen = gtk_widget_get_screen (window);
-#if GTK_CHECK_VERSION (2, 90, 8)
 	visual = gdk_screen_get_rgba_visual(screen);
 	if (visual)
 		gtk_widget_set_visual(GTK_WIDGET(window), visual);
-#else
-	colormap = gdk_screen_get_rgba_colormap (screen);
-	if (colormap)
-	    gtk_widget_set_colormap(window, colormap);
-#endif
 
 	if (use_scrolled_window) {
 		scrolled_window = gtk_scrolled_window_new (NULL, NULL);
@@ -1091,9 +1076,7 @@ main(int argc, char **argv)
 		if (!gtk_window_parse_geometry (GTK_WINDOW(window), geometry)) {
 			g_warning (_("Could not parse the geometry spec passed to --geometry"));
 		}
-	}
-#if GTK_CHECK_VERSION(2, 91, 0)
-	else {
+	} else {
 		/* As of GTK+ 2.91.0, the default size of a window comes from its minimum
 		 * size not its natural size, so we need to set the right default size
 		 * explicitly */
@@ -1101,7 +1084,6 @@ main(int argc, char **argv)
 						 vte_terminal_get_column_count (terminal),
 						 vte_terminal_get_row_count (terminal));
 	}
-#endif
 
 	gtk_widget_show_all(window);
 
